==> letsnet-services-1.0.2.tgz: package/lib/ProductAPI.js <==
var request = require('request')
    options = require('./options'),
    ProdAPIRequestURL = options.server.base + options.server.ProdAPIRequestURL

module.exports = function(defaults) {

    let getCategories = function() {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': 'Bearer ' + defaults.apikey
                },
                url: ProdAPIRequestURL + '/getCategories'
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductsByCategoryName = function(categoryname, start, end) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': 'Bearer ' + defaults.apikey
                },
                url: ProdAPIRequestURL + '/getCategoryProducts/' + categoryname + '/' + start + '/' + end
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductsByCategoryID = function(categoryid, start, end) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': 'Bearer ' + defaults.apikey
                },
                url: ProdAPIRequestURL + '/getCategoryProducts/' + categoryid + '/' + start + '/' + end
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getCategoryProperties = function(categoryid) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': 'Bearer ' + defaults.apikey
                },
                url: ProdAPIRequestURL + '/getCategoryProperties/' + categoryid
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductInfo = function(prodid) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': 'Bearer ' + defaults.apikey
                },
                url: ProdAPIRequestURL + '/getProductInfo/' + prodid
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    var model = {}

    model.getCategories = function(callback) {
        getCategories()
        .then(function(categories) {
            callback(null, categories)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductsByCategoryName = function(callback) {
        getProductsByCategoryName()
        .then(function(products) {
            callback(null, products)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductsByCategoryID = function(categoryid, start, end, callback) {
        getProductsByCategoryID(categoryid, start, end)
        .then(function(products) {
            callback(null, products)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getCategoryProperties = function(categoryid, callback) {
        getCategoryProperties(categoryid)
        .then(function(properties) {
            callback(null, properties)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductInfo = function(prodid, callback) {
        getProductInfo(prodid)
        .then(function(product) {
            callback(null, product)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    return model
}

==> letsnet-services-1.1.1.tgz: package/lib/ProductAPI.js <==
var request = require('request')
    options = require('./options'),
    ProdAPIRequestURL = options.server.base + options.server.ProdAPIRequestURL

module.exports = function(defaults) {

    let getAllProducts = function(s, e) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getAllProducts/${s}/${e}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getCategories = function() {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + '/getCategories'
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getCategoryDocument = function(cID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getCategoryDocument/${cID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getCategoryProducts = function(cID, s, e) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getCategoryProducts/${cID}/${s}/${e}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err == true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getCategoryProperties = function(cID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getCategoryProperties/${cID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getCategoryProperty = function(pID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getCategoryProperty/${pID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getCategoryPropertyByValueID = function(vID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getCategoryPropertyByValueID/${vID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getSpecialCategories = function(vID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + '/getSpecialCategories'
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getNormalCategories = function(vID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + '/getNormalCategories'
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductInfo = function(pID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getProductInfo/${pID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductMainImage = function(pID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getProductMainImage/${pID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductProperties = function(pID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getProductProperties/${pID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductProperty = function(pID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getProductProperty/${pID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductPropertyImages = function(pID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getProductPropertyImages/${pID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }

    let getProductPropertyReference = function(pID) {
        return new Promise((fulfill, reject) => {
            request.get({
                headers: {
                    'Content-Type' : 'application/json',
                    'Authorization': `Bearer ${defaults.apikey}`
                },
                url: ProdAPIRequestURL + `/getProductPropertyReference/${pID}`
            },
            (err, res, body) => {
                if(err || err != null) reject({error: true, message: 'Can not connect to http://node.letsnet.hu server ...'})
                else {
                    response = JSON.parse(body)
                    if(response.err = true) reject(response)
                    else fulfill(response)
                }
            });
        })
    }


    var model = {}


    // all functions

    model.getAllProducts = function(s, e, callback) {
        getAllProducts(s, e)
        .then(function(products) {
            callback(null, products)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    // category functions

    model.getCategories = function(callback) {
        getCategories()
        .then(function(categories) {
            callback(null, categories)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getCategoryDocument = function(cID, callback) {
        getCategoryDocument(cID)
        .then(function(document) {
            callback(null, document)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getCategoryProducts = function(cID, s, e, callback) {
        getCategoryProducts(cID, s, e)
        .then(function(products) {
            callback(null, products)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getCategoryProperties = function(cID, callback) {
        getCategoryProperties(cID)
        .then(function(properties) {
            callback(null, properties)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getCategoryProperty = function(pID, callback) {
        getCategoryProperty(pID)
        .then(function(property) {
            callback(null, property)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getCategoryPropertyByValueID = function(pID, callback) {
        getCategoryPropertyByValueID(pID)
        .then(function(property) {
            callback(null, property)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getSpecialCategories = function(callback) {
        getSpecialCategories()
        .then(function(property) {
            callback(null, property)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getNormalCategories = function(callback) {
        getNormalCategories()
        .then(function(property) {
            callback(null, property)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    // product functions

    model.getProductInfo = function(pID, callback) {
        getProductInfo(pID)
        .then(function(product) {
            callback(null, product)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductMainImage = function(pID, callback) {
        getProductMainImage(pID)
        .then(function(product) {
            callback(null, product)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductProperties = function(pID, callback) {
        getProductProperties(pID)
        .then(function(properties) {
            callback(null, properties)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductProperty = function(pID, callback) {
        getProductProperty(pID)
        .then(function(property) {
            callback(null, property)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductPropertyImages = function(pID, callback) {
        getProductPropertyImages(pID)
        .then(function(product) {
            callback(null, product)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    model.getProductPropertyReference = function(pID, callback) {
        getProductPropertyReference(pID)
        .then(function(product) {
            callback(null, product)
        })
        .catch(function(err) {
            callback(err, null)
        })
    }

    // ending

    return model
}
